==> estateplat-common-1.1.0-20160902.030133-173-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwzl.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_FWZL")
public class BdcFwzl extends QllxParent implements QllxVo {
    private String dw;//单位
    private String zxywh;//注销业务号
    private Date zxdjsj;//注销登记时间
    private Date zxdbr;//注销登簿人
    private String zxyy;//注销原因
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fj;//附记
    private String bz;//备注

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public Date getZxdjsj() {
        return zxdjsj;
    }

    public void setZxdjsj(Date zxdjsj) {
        this.zxdjsj = zxdjsj;
    }

    public Date getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(Date zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.3-20180530.031643-101-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwzl.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_FWZL")
public class BdcFwzl extends QllxParent implements QllxVo {
    private String dw;//单位
    private String zxywh;//注销业务号
    private Date zxdjsj;//注销登记时间
    private Date zxdbr;//注销登簿人
    private String zxyy;//注销原因
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fj;//附记
    private String bz;//备注
    private Date zlxysdsj;//租赁协议送达时间

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public Date getZxdjsj() {
        return zxdjsj;
    }

    public void setZxdjsj(Date zxdjsj) {
        this.zxdjsj = zxdjsj;
    }

    public Date getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(Date zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getZlxysdsj() {
        return zlxysdsj;
    }

    public void setZlxysdsj(Date zlxysdsj) {
        this.zlxysdsj = zlxysdsj;
    }
}
